package MakeWorld::Mogrify::Fillin;

use strict;
use warnings;

use IO::File;
use File::Spec::Functions qw[ catfile ];
use Template::Tiny;


use MakeWorld::Global;
use MakeWorld::Utils qw[ find_exe ];
use MakeWorld::Check qw[ check ];
use MakeWorld::Log;
use MakeWorld::Interpolate;

################################################################################
# execute a command

sub verify {

    my ( $class, $opts, $need_hook ) = @_;

    return check( {
		   tpl => { required => 1 },
		   output => { required => 1 },
		   hook => { required => $need_hook },
		   vars => { default => {} },
		  }, $opts
		);
}


sub mogrify
{
    my ( $class, $pkg, $opts ) = @_;

    # find template file
    my $tfile = substr( $opts->{tpl}, 0, 2 ) eq './'
	    ? $opts->{tpl}
	    : (grep { -f $_ }
	       map { glob(catfile($_,$opts->{tpl})) } @{$opt{srcdir}})[0];

    die "<fillin>: couldn't find template file: $opts->{tpl}\n"
      unless $tfile && -f $tfile;

    my $fh = IO::File->new( $tfile )
      or die( "<fillin>: unable to open template file $tfile\n" );

    msgp( "<fillin>", MakeWorld::Log::Info, "$tfile $opts->{output}\n" );

    my $template = eval { local $/ = undef; $fh->getline };

    my $tpl = Template::Tiny->new;
    my $vars = interpolate_vars( $opts->{vars}, $pkg->archive );

    $tpl->process( \$template, $vars, \(my $output) );

    $fh = IO::File->new( $opts->{output}, 'w' )
      or die( "<fillin>: unable to create template output file: $opts->{output}\n" );

    $fh->print( $output );

    return;
}

1;
