#!@PERL@

# --8<--8<--8<--8<--
#
# Copyright (C) 2010 Smithsonian Astrophysical Observatory
#
# This file is part of make-world
#
# make-world is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# make-world is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
#       Free Software Foundation, Inc.
#       51 Franklin Street, Fifth Floor
#       Boston, MA  02110-1301, USA
#
# -->8-->8-->8-->8--


use strict;
use warnings;

package MakeWorld::Package::PerlModule;

use base 'MakeWorld::Package';
use Carp;

use File::Spec::Functions qw/ catdir /;

use MakeWorld::Global;
use MakeWorld::Run;

sub matches_contents {  -f 'Makefile.PL'; }


sub configure
{
    my $self = shift;

    $self->SUPER::configure && return;

    # check for configure file. if its a dryrun, it's probable that the
    # source hasn't been unarchived and we won't see the configure file.
    # just assume its there. can't hurt!
    if ( -f 'Makefile.PL' || $opt{dryrun} )
    {
	my @args;

	if ( eval 'use ExtUtils::MakeMaker 6.31; 1;' )
	{
	    @args = ( "INSTALL_BASE=$opt{prefix}" );
	}

	else
	{
	    require Config;

	    @args = map { $_->[0] . '=' . $_->[1] }
	      [ INSTALLDIRS     => 'perl' ],
	      [ INSTALLARCHLIB  => "$opt{prefix}/lib/perl5/$Config::Config{archname}" ],
	      [ INSTALLPRIVLIB  => "$opt{prefix}/lib/perl5" ],
	      [ INSTALLBIN      => "$opt{prefix}/bin" ],
	      [ INSTALLSCRIPT   => "$opt{prefix}/bin" ],
	      [ INSTALLMAN1DIR  => "$opt{prefix}/man/man1" ],
	      [ INSTALLMAN3DIR  => "$opt{prefix}/man/man3" ];
	}


	push @args, $self->{option}{configure}{arg};

	run( qw( perl Makefile.PL), @args )
	  or die( "error configuring package\n" );
    }
}

sub build
{
    my $self = shift;

    $self->SUPER::build && return;

    my @cmd = ( $opt{make_cmd} );

    push @cmd, $self->{option}{build}{arg};

    run( @cmd  )
	or die( "error building package\n" );
}

sub test
{
    my $self = shift;

    $self->SUPER::test && return;

    run( $opt{make_cmd}, 'test' )
      or die( "error testing package\n" );
}


sub install
{
    my $self = shift;

    $self->SUPER::install && return;

    run( $opt{make_cmd}, 'install' )
      or die( "error installing package\n" );
}

1;
